package com.gic.haoban.manage.web.controller;

import java.util.HashSet;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

import com.gic.haoban.auth.api.dto.UserRightDetailDTO;
import com.gic.haoban.manage.api.dto.StoreRangeInfoDTO;
import com.gic.haoban.manage.api.dto.WxEnterpriseRelationDetailDTO;
import com.gic.haoban.manage.api.service.WxEnterpriseRelatedApiService;
import com.gic.haoban.manage.web.vo.LoginVO;
import com.gic.haoban.manage.web.vo.StoreGroupVo;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.gic.enterprise.api.dto.PowerStoreGroupDTO;
import com.gic.enterprise.api.service.StoreGroupService;
import com.gic.haoban.base.api.common.BasePageInfo;
import com.gic.haoban.common.utils.HaobanResponse;
import com.gic.haoban.manage.web.errCode.HaoBanErrCode;

@RestController
public class GicDepartmentController extends WebBaseController{
	
	private static Logger logger  = LoggerFactory.getLogger(GicDepartmentController.class);
	
	@Autowired
	private StoreGroupService storeGroupService;

	@Autowired
	private WxEnterpriseRelatedApiService wxEnterpriseRelatedApiService;
	
	@RequestMapping("gic-department-list")
	public HaobanResponse departmentList(String enterpriseId, String keyWord) {

		List<PowerStoreGroupDTO>  departmentList = storeGroupService.getStoreGroupList(enterpriseId, keyWord);
		return resultResponse(HaoBanErrCode.ERR_1,departmentList);

	}

	@RequestMapping("gic-store-group-list")
	public HaobanResponse storeGroupList(String enterpriseId, String keyWord) {
		LoginVO loginUser = this.getLoginUser();
		String wxEnterpriseId = loginUser.getWxEnterpriseId();
		List<PowerStoreGroupDTO> departmentList = storeGroupService.getStoreGroupList(enterpriseId, keyWord);
		List<StoreRangeInfoDTO> rangeInfoDTOList = wxEnterpriseRelatedApiService.listAllBindStoreOrGroup(enterpriseId);
		Set<String> groupIds = new HashSet<>();
		if (CollectionUtils.isNotEmpty(rangeInfoDTOList)) {
			groupIds = rangeInfoDTOList.stream().filter(dto -> (!dto.getWxEnterpriseId().equals(wxEnterpriseId)) && dto.getRelationType() == 1)
					.map(dto -> dto.getRelationId()).collect(Collectors.toSet());
		}
		Set<String> finalGroupIds = groupIds;
		List<StoreGroupVo> ret = departmentList.stream().map(dto -> {
			StoreGroupVo storeGroupVo = new StoreGroupVo();
			storeGroupVo.setRelationId(dto.getStoreGroupId());
			storeGroupVo.setParentRelationId(dto.getParentGroupId());
			storeGroupVo.setIsBind(finalGroupIds.contains(dto.getStoreGroupId()) ? 1 : 0);
			storeGroupVo.setRelationType(1);
			storeGroupVo.setRelationName(dto.getStoreGroupName());
			return storeGroupVo;
		}).collect(Collectors.toList());
		return resultResponse(HaoBanErrCode.ERR_1, ret);

	}

}
